@@ -1,5 +1,4 @@
 #' @useDynLib xml2, .registration = TRUE
-#' @importFrom Rcpp sourceCpp
 NULL
 
 # node -------------------------------------------------------------------------
@@ -8,14 +7,16 @@ xml_node <- function(node = NULL, doc = NULL) {
   if (inherits(node, "xml_node")) {
     node
   } else {
-    structure(list(node = node, doc = doc), class = "xml_node")
+    out <- list(node = node, doc = doc)
+    class(out) <- "xml_node"
+    out
   }
 }
 
 #' @export
 as.character.xml_node <- function(x, ..., options = "format", encoding = "UTF-8") {
   options  <- parse_options(options, xml_save_options())
-  node_write_character(x$node, options = options, encoding = encoding)
+  .Call(node_write_character, x$node, encoding, options)
 }
 
 #' @export
@@ -34,12 +35,14 @@ print.xml_missing <- function(x, width = getOption("width"), max_n = 20, ...) {
 # document ---------------------------------------------------------------------
 
 xml_document <- function(doc) {
-  if (doc_has_root(doc)) {
-    x <- xml_node(doc_root(doc), doc)
+  if (.Call(doc_has_root, doc)) {
+    x <- xml_node(.Call(doc_root, doc), doc)
     class(x) <- c("xml_document", class(x))
     x
   } else {
-    structure(list(doc = doc), class = "xml_document")
+    out <- list(doc = doc)
+    class(out) <- "xml_document"
+    out
   }
 }
 
@@ -47,7 +50,7 @@ doc_type <- function(x) {
   if (is.null(x$doc)) {
     return("xml")
   }
-  if (doc_is_html(x$doc)) {
+  if (.Call(doc_is_html, x$doc)) {
     "html"
   } else {
     "xml"
@@ -67,16 +70,17 @@ print.xml_document <- function(x, width = getOption("width"), max_n = 20, ...) {
 #' @export
 as.character.xml_document <- function(x, ..., options = "format", encoding = "UTF-8") {
   options  <- parse_options(options, xml_save_options())
-  doc_write_character(x$doc, options = options, encoding = encoding)
+  .Call(doc_write_character, x$doc, encoding, options)
 }
 
 # nodeset ----------------------------------------------------------------------
 
 xml_nodeset <- function(nodes = list(), deduplicate = TRUE) {
   if (isTRUE(deduplicate)) {
-    nodes <- nodes[!nodes_duplicated(nodes)]
+    nodes <- nodes[!.Call(nodes_duplicated, nodes)]
   }
-  structure(nodes, class = "xml_nodeset")
+  class(nodes) <- "xml_nodeset"
+  nodes
 }
 
 #' @param nodes A list (possible nested) of external pointers to nodes
@@ -201,7 +205,9 @@ format_attributes <- function(x) {
 #' @export
 #' @keywords internal
 xml_missing <- function() {
-  structure(list(), class = "xml_missing")
+  out <- list()
+  class(out) <- "xml_missing"
+  out
 }
 
 #' @export
@@ -244,7 +250,8 @@ as.character.xml_missing <- function(x, ...) {
 #' as.character(x)
 #' @export
 xml_cdata <- function(content) {
-  structure(content, class = "xml_cdata")
+  class(content) <- "xml_cdata"
+  content
 }
 
 #' Construct a comment node
@@ -256,7 +263,8 @@ xml_cdata <- function(content) {
 #' as.character(x)
 #' @export
 xml_comment <- function(content) {
-  structure(content, class = "xml_comment")
+  class(content) <- "xml_comment"
+  content
 }
 
 #' Construct a document type definition
@@ -282,5 +290,7 @@ xml_comment <- function(content) {
 #' <doc>This is a valid document &foo; !</doc>')
 #' @export
 xml_dtd <- function(name = "", external_id = "", system_id = "") {
-  structure(list(name = name, external_id = external_id, system_id = system_id), class = "xml_dtd")
+  out <- list(name = name, external_id = external_id, system_id = system_id)
+  class(out) <- "xml_dtd"
+  out
 }
